[English](README.md)

# Яр. Написання українських числівників

Ця бібліотека перетворює числа на текст.

## Доступні функції

- [x] Написання числівників – перетворення чисел на текст.
- [x] Відмінювання числівників – написання числівників в будь-якій граматичній формі.
- [x] Узгодження - узгодження граматичних форм складених числівників.
- [x] На́голоси.
- [x] Написання кількісних числівників в діапазоні [0...1×10<sup>27</sup>)<sup>_1_, _2_</sup>.
- [x] Написання порядкових числівників в діапазоні [0...1×10<sup>27</sup>)<sup>_1_</sup>.
- [x] Написання дробових числівників з цілою частиною. Кожен фрагмент в діапазоні [0...1×10<sup>27</sup>).
- [x] Написання десяткових числівників в діапазоні (0...1×10<sup>27</sup>) з точністю до 1×10<sup>-27</sup> <sup>_3_</sup>.

---

<sup>_1_</sup> Числівники за межами діапазонів будуть написані по-цифрах, відмінюватиметься тільки останнє слово.

<sup>_2_</sup> 1×10<sup>27</sup> це `1 000 000 000 000 000 000 000 000 000`, один октильйо́н

<sup>_3_</sup> 1×10<sup>-27</sup> це `0,000 000 000 000 000 000 000 000 001`, одна октильйо́нна

## Заплановані функції

- [ ] Відʼємні числа.
- [ ] Cкорочені порядкові числа (наприклад "1-й", "1000-на").
- [ ] Експоненційний запис (наприклад "1e5").
- [ ] Римські числа (наприклад "XIV").

## Доступні граматичні категорії

- відмінки: називний (nominative), родовий (genitive), давальний (dative), знахідний (accusative), орудний (instrumental), місцевий (locative), клична форма (vocative)
- роди: чоловічий (masculine), жіночий (feminine), середній (neuter)
- однина (singular), множина (plural)
- істота (animate), неістота (inanimate)
